/*
 * [The "BSD licence"]
 * Copyright (c) 2012 Dandelion
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.github.dandelion.datatables.jsp.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.github.dandelion.datatables.core.callback.Callback;
import com.github.dandelion.datatables.core.callback.CallbackType;
import com.github.dandelion.datatables.core.util.StringUtils;

/**
 * Tag used to add DataTables' callbacks.
 *
 * @author Thibault Duchateau
 * @since 0.8.9
 */
public class CallbackTag extends TagSupport {
	private static final long serialVersionUID = -3453884184847355817L;

	// Logger
	private static Logger logger = LoggerFactory.getLogger(CallbackTag.class);
		
	// Tag attributes
	private String type;
	private String function;
	
	/**
	 * We test that the tag is in the right place.
	 */
	public int doStartTag() throws JspException {

		AbstractTableTag parent = (AbstractTableTag) findAncestorWithClass(this, AbstractTableTag.class);

		// There isn't an ancestor of given class
		if (parent == null) { 
			throw new JspException("CallbackTag must be inside the AbstractTableTag");
		}

		return SKIP_BODY;
	}
	
	/**
	 * Processes the tag.
	 */
	public int doEndTag() throws JspException {
		
		// Get parent tag
		AbstractTableTag parent = (AbstractTableTag) findAncestorWithClass(this, AbstractTableTag.class);

		// Evaluate the tag only once
		if(parent.isFirstIteration()){
			
			CallbackType callbackType = null;
			try {
				callbackType = CallbackType.valueOf(this.type.toUpperCase().trim());
			} catch (IllegalArgumentException e) {
				logger.error("{} is not a valid value among {}. Please choose a valid one.",
						callbackType, CallbackType.values());
				throw new JspException(e);
			}

			// The callback has already been registered
			if(parent.getTable().getTableConfiguration().hasCallback(callbackType)){
				parent.getTable().getTableConfiguration().getCallback(callbackType)
						.appendCode((callbackType.hasReturn() ? "return " : "") + function + "(" + StringUtils.join(callbackType.getArgs(), ",") + ");");
			}
			// The callback hasn't been registered yet
			else{
				parent.getTable()
						.getTableConfiguration()
						.registerCallback(
								new Callback(callbackType, 
										(callbackType.hasReturn() ? "return " : "") + function + "("
										+ StringUtils.join(callbackType.getArgs(), ",") + ");"));
			}
		}
		
		return EVAL_PAGE;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getFunction() {
		return function;
	}

	public void setFunction(String function) {
		this.function = function;
	}
}